@@ -530,6 +530,7 @@ class txU1(object):
 				query.viewitems() if v is not None )
 		api_url = self._api_url(url, query, content=content)
 		request_kwz.setdefault('decode', 'json')
+		request_kwz.setdefault('raise_for', dict()).setdefault(404, DoesNotExist)
 
 		def _auth_headers(url, method, body, mime, base):
 			url = url.split(' ', 1)[0] # XXX: no idea why API does that, bug?
@@ -562,11 +563,17 @@ class txU1(object):
 
 	def info_public_files(self): return self('public_files')
 
+	@defer.inlineCallbacks
+	def get_quota(self):
+		'Return tuple of (bytes_available, bytes_quota).'
+		du, ds = op.itemgetter('used_bytes', 'max_bytes')((yield self()))
+		defer.returnValue((ds - du, ds))
+
 
 	@defer.inlineCallbacks
 	def volume_info(self, vol=None, type_filter=None):
 		'Get list of all volumes or info for the one specified.'
-		vols = yield self(join('volumes', vol), raise_for={404: DoesNotExist})
+		vols = yield self(join('volumes', vol))
 		if not isinstance(vols, list): vols = [vols]
 		if type_filter is not None:
 			vols = list(vol for vol in vols if vol['type'] == type_filter)
@@ -597,14 +604,17 @@ class txU1(object):
 
 	def _prepend_volume(func):
 		@defer.inlineCallbacks
+		@ft.wraps(func)
 		def _func(self, path, vol=None, **kwz):
-			if not vol: vol = yield self.get_default_volume()
+			if vol is None and not path.lstrip('/').startswith('~/'):
+				vol = yield self.get_default_volume()
 			defer.returnValue((yield func(self, join(vol, path), **kwz)))
 		return _func
 
 	def _content_path(func):
 		@defer.inlineCallbacks
-		def _func(self, path, vol=None, content_path=None, **kwz):
+		@ft.wraps(func)
+		def _func(self, path=None, vol=None, content_path=None, **kwz):
 			if not content_path:
 				if not vol: vol = yield self.get_default_volume()
 				content_path = (yield self(join(vol, path), raise_for={404: DoesNotExist}))['content_path']
@@ -623,6 +633,7 @@ class txU1(object):
 
 	@_prepend_volume
 	def node_mkdir(self, path=''):
+		'Does not raise any errors if dir already exists.'
 		return self(path, data=dict(kind='directory'), encode='json', method='put')
 
 	@_prepend_volume
@@ -669,6 +680,24 @@ class txU1(object):
 			encode='json', method='put', raise_for={400: DoesNotExist})
 
 
+class txU1Persistent(txU1):
+
+	#: Path to configuration file to use in from_conf() by default.
+	conf_path_default = b'~/.u1rc'
+
+	@classmethod
+	def from_conf(cls, path=None, **overrides):
+		import yaml
+		if path is None:
+			path = cls.conf_path_default
+			log.debug('Using default state-file path: {}'.format(path))
+		path = os.path.expanduser(path)
+		with open(path) as src:
+			conf = yaml.load(src.read())
+		conf.update(overrides)
+		return cls(**conf)
+
+
 
 if __name__ == '__main__':
 	logging.basicConfig(level=logging.DEBUG)
